==> haskell-http3-0.0.5-45-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http3.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http3
version:              0.0.5
visibility:           public
id:                   http3-0.0.5-499qUrZY3YwLOFPDYiy2D3
key:                  http3-0.0.5-499qUrZY3YwLOFPDYiy2D3
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/http3
synopsis:             HTTP/3 library
description:          HTTP/3 library including frames, QPACK, client and server.
category:             Network
abi:                  f7f957ab4e856bdc0e0fac5d61487173
exposed:              True
exposed-modules:
    Network.HQ.Client Network.HQ.Server Network.HTTP3.Client
    Network.HTTP3.Internal Network.HTTP3.Server Network.QPACK
    Network.QPACK.Internal

hidden-modules:
    Imports Network.HTTP3.Config Network.HTTP3.Context
    Network.HTTP3.Control Network.HTTP3.Error Network.HTTP3.Frame
    Network.HTTP3.Recv Network.HTTP3.Send Network.HTTP3.Settings
    Network.HTTP3.Stream Network.QPACK.Error Network.QPACK.HeaderBlock
    Network.QPACK.HeaderBlock.Decode Network.QPACK.HeaderBlock.Encode
    Network.QPACK.HeaderBlock.Prefix Network.QPACK.Instruction
    Network.QPACK.Table Network.QPACK.Table.Dynamic
    Network.QPACK.Table.RevIndex Network.QPACK.Table.Static
    Network.QPACK.Token Network.QPACK.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http3-0.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http3-0.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http3-0.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http3
hs-libraries:         HShttp3-0.0.5-499qUrZY3YwLOFPDYiy2D3
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-JVWVUVinOoKLKsx1rHKuw7 containers-0.6.7
    http-types-0.12.4-Kfgn5nq0Uw5JM2IxBj4ZY1
    http2-4.2.1-CzvTPwTo57mKJV62bZlDQQ
    network-3.1.4.0-BMQQjwbPvFR57Ka0tgIiy2
    network-byte-order-0.1.7-D2CHdiOOdOK1rEVBtge3lM
    quic-0.1.20-1heaoVK4PZPFM4XZ4jPzEl
    sockaddr-0.0.1-AwS4gKEOEhbBUZfZ6YGRmN stm-2.5.1.0
    time-manager-0.0.1-BmtyhfJgyqL20WWsraI0DS
    unliftio-0.2.25.1-83PwQVOhURl3H5nxoMcX3o

haddock-interfaces:   /usr/share/doc/haskell-http3/html/http3.haddock
haddock-html:         /usr/share/doc/haskell-http3/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http3-0.0.9-4-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http3.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http3
version:              0.0.9
visibility:           public
id:                   http3-0.0.9-GCpXd2HmVkt9lHXxQFOoxq
key:                  http3-0.0.9-GCpXd2HmVkt9lHXxQFOoxq
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/http3
synopsis:             HTTP/3 library
description:          HTTP/3 library including frames, QPACK, client and server.
category:             Network
abi:                  47c9a32a181f6ed1273f8b0f804d1e5f
exposed:              True
exposed-modules:
    Network.HQ.Client Network.HQ.Server Network.HTTP3.Client
    Network.HTTP3.Internal Network.HTTP3.Server Network.QPACK
    Network.QPACK.Internal

hidden-modules:
    Imports Network.HTTP3.Config Network.HTTP3.Context
    Network.HTTP3.Control Network.HTTP3.Error Network.HTTP3.Frame
    Network.HTTP3.Recv Network.HTTP3.Send Network.HTTP3.Settings
    Network.HTTP3.Stream Network.QPACK.Error Network.QPACK.HeaderBlock
    Network.QPACK.HeaderBlock.Decode Network.QPACK.HeaderBlock.Encode
    Network.QPACK.HeaderBlock.Prefix Network.QPACK.Instruction
    Network.QPACK.Table Network.QPACK.Table.Dynamic
    Network.QPACK.Table.RevIndex Network.QPACK.Table.Static
    Network.QPACK.Token Network.QPACK.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http3-0.0.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http3-0.0.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http3-0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http3
hs-libraries:         HShttp3-0.0.9-GCpXd2HmVkt9lHXxQFOoxq
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-4psXWcL2Or6Ff92NkDcfKY containers-0.6.7
    http-types-0.12.4-3Rkn4NOOYhzvBVdRap5Ii
    http2-5.1.0-DvFurAfYXnIK8gXBawibUJ
    network-3.1.4.0-2g2oEkgQCahBaM3HvlpVNW
    network-byte-order-0.1.7-D2CHdiOOdOK1rEVBtge3lM
    quic-0.1.24-K0NORj2SaRC8me2Q1BkbzS
    sockaddr-0.0.1-5wkLl3vZ0Rh8aVedKWnAr8 stm-2.5.1.0
    time-manager-0.0.1-64tMhcn8tqI9L49xj4n2fe
    unliftio-0.2.25.1-jUDvU4O8PS8SoQvWmG5yt

haddock-interfaces:   /usr/share/doc/haskell-http3/html/http3.haddock
haddock-html:         /usr/share/doc/haskell-http3/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
